@@ -43,8 +43,8 @@ from mopytools.util import (run, envname, update_cmd, step,
 
 @step('Updating the repo')
 def updating_repo(name, channel, specific_tags, force=False):
-    if not force and has_changes():
-        print('the code was changed locally, aborting!')
+    if not force and has_changes() and channel != 'dev':
+        print('The code was changed locally, aborting!')
         print('You can use --force but all uncommited '
               'changes will be discarded.')
         sys.exit(0)
